@@ -17,9 +17,9 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/main.cpp" line="52"/>
+        <location filename="../src/main.cpp" line="51"/>
         <source>unknown request</source>
-        <translation>Neznámý požadavek</translation>
+        <translation>neznámý požadavek</translation>
     </message>
 </context>
 </TS>
